@@ -551,8 +551,9 @@ public:
     {
       number_of_variable_length_records = 1;
       offset_to_point_data += 54;
-      vlrs = (LASvlr*)calloc(number_of_variable_length_records, sizeof(LASvlr));
+      vlrs = (LASvlr*)malloc(sizeof(LASvlr));
     }
+    memset((void*)(&(vlrs[i])), 0, sizeof(LASvlr));
     vlrs[i].reserved = 0; // used to be 0xAABB
     strncpy(vlrs[i].user_id, user_id, 16);
     vlrs[i].record_id = record_id;
