@@ -2,11 +2,11 @@
 ===============================================================================
 
   FILE:  lasreader_bil.cpp
-
+  
   CONTENTS:
-
+  
     see corresponding header file
-
+  
   PROGRAMMERS:
 
     martin.isenburg@rapidlasso.com  -  http://rapidlasso.com
@@ -21,20 +21,17 @@
 
     This software is distributed WITHOUT ANY WARRANTY and without even the
     implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
+  
   CHANGE HISTORY:
-
-    20 December 2016 -- by Jean-Romain Roussel -- Change fprint(stderr, ...), raise an exeption
-
+  
     see corresponding header file
-
+  
 ===============================================================================
 */
 #include "lasreader_bil.hpp"
 
 #include <stdlib.h>
 #include <string.h>
-#include <stdexcept>
 
 #ifdef _WIN32
 #include <windows.h>
@@ -44,7 +41,7 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
 {
   if (file_name == 0)
   {
-    throw std::runtime_error(std::string("ERROR: fine name pointer is zero"));
+    REprintf("ERROR: file name pointer is zero\n");
     return FALSE;
   }
 
@@ -56,7 +53,7 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
 
   if (!read_hdr_file(file_name))
   {
-    throw std::runtime_error(std::string("ERROR: reading the *.hdr file for '%s'")); //file_name
+    REprintf("ERROR: reading the *.hdr file for '%s'\n", file_name);
     return FALSE;
   }
 
@@ -64,7 +61,7 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
 
   if (!read_blw_file(file_name))
   {
-    throw std::runtime_error(std::string("WARNING: reading the *.blw file for '%s'")); //file_name
+    REprintf("WARNING: reading the *.blw file for '%s'\n", file_name);
   }
 
   // check that we have all the needed info
@@ -72,25 +69,25 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
   if (xdim <= 0)
   {
     xdim = 1;
-    throw std::runtime_error(std::string("WARNING: xdim was not set. setting to %g")); //xdim
+    REprintf("WARNING: xdim was not set. setting to %g\n", xdim);
   }
 
   if (ydim <= 0)
   {
     ydim = 1;
-    throw std::runtime_error(std::string("WARNING: ydim was not set. setting to %g")); //ydim
+    REprintf("WARNING: ydim was not set. setting to %g\n", ydim);
   }
 
   if (ulxcenter == F64_MAX)
   {
     ulxcenter = 0.5*xdim;
-    throw std::runtime_error(std::string("WARNING: ulxcenter was not set. setting to %g")); //ulxcenter
+    REprintf("WARNING: ulxcenter was not set. setting to %g\n", ulxcenter);
   }
 
   if (ulycenter == F64_MAX)
   {
     ulycenter = (-0.5+nrows)*ydim;
-    throw std::runtime_error(std::string("WARNING: ulycenter was not set. setting to %g")); //ulycenter
+    REprintf("WARNING: ulycenter was not set. setting to %g\n", ulycenter);
   }
 
   // open the BIL file
@@ -98,13 +95,13 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
   file = fopen(file_name, "rb");
   if (file == 0)
   {
-    throw std::runtime_error(std::string("ERROR: cannot open file '%s'")); //file_name
+    REprintf( "ERROR: cannot open file '%s'\n", file_name);
     return FALSE;
   }
 
   if (setvbuf(file, NULL, _IOFBF, 2*LAS_TOOLS_IO_IBUFFER_SIZE) != 0)
   {
-    throw std::runtime_error(std::string("WARNING: setvbuf() failed with buffer size %d")); //2*LAS_TOOLS_IO_IBUFFER_SIZE
+    REprintf( "WARNING: setvbuf() failed with buffer size %d\n", 2*LAS_TOOLS_IO_IBUFFER_SIZE);
   }
 
   // populate the header as much as it makes sense
@@ -274,7 +271,7 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
   }
   else
   {
-    throw std::runtime_error(std::string("WARNING: BIL raster contains only no data values"));
+    REprintf("WARNING: BIL raster contains only no data values\n");
     header.min_z = 0;
     header.max_z = 0;
   }
@@ -288,7 +285,7 @@ BOOL LASreaderBIL::read_hdr_file(const CHAR* file_name)
 {
   if (file_name == 0)
   {
-    throw std::runtime_error(std::string("ERROR: fine name pointer is zero"));
+    REprintf("ERROR: file name pointer is zero\n");
     return FALSE;
   }
 
@@ -301,7 +298,7 @@ BOOL LASreaderBIL::read_hdr_file(const CHAR* file_name)
 
   if ((len == 0) && (file_name_hdr[len] != '.'))
   {
-    throw std::runtime_error(std::string("ERROR: file name '%s' is not a valid BIL file")); //file_name
+    REprintf("ERROR: file name '%s' is not a valid BIL file\n", file_name);
     return FALSE;
   }
 
@@ -323,7 +320,7 @@ BOOL LASreaderBIL::read_hdr_file(const CHAR* file_name)
     if (file == 0)
     {
       file_name_hdr[len] = '\0';
-      throw std::runtime_error(std::string("ERROR: cannot open files '%s.hdr' or '%s.HDR'")); //file_name_hdr, file_name_hdr
+      REprintf( "ERROR: cannot open files '%s.hdr' or '%s.HDR'\n", file_name_hdr, file_name_hdr);
       return FALSE;
     }
   }
@@ -376,12 +373,12 @@ BOOL LASreaderBIL::read_hdr_file(const CHAR* file_name)
       {
         if (strcmp(layout, "bil") && strcmp(layout, "BIL"))
         {
-          throw std::runtime_error(std::string("WARNING: %s '%s' not recognized by LASreader_bil")); //dummy, layout
+          REprintf( "WARNING: %s '%s' not recognized by LASreader_bil\n", dummy, layout);
         }
       }
       else
       {
-        throw std::runtime_error(std::string("WARNING: argument of %s missing for LASreader_bil")); //dummy
+        REprintf( "WARNING: argument of %s missing for LASreader_bil\n", dummy);
       }
     }
     else if (strstr(line, "pixeltype") || strstr(line, "PIXELTYPE"))
@@ -390,7 +387,7 @@ BOOL LASreaderBIL::read_hdr_file(const CHAR* file_name)
       sscanf(line, "%s %s", dummy, pixeltype);
       if (strcmp(pixeltype, "float") && strcmp(pixeltype, "FLOAT"))
       {
-        throw std::runtime_error(std::string("WARNING: pixeltype '%s' not recognized by LASreader_bil")); //pixeltype
+        REprintf( "WARNING: pixeltype '%s' not recognized by LASreader_bil\n", pixeltype);
       }
       else
       {
@@ -407,7 +404,7 @@ BOOL LASreaderBIL::read_hdr_file(const CHAR* file_name)
       sscanf(line, "%s %s", dummy, byteorder);
       if (strcmp(byteorder, "i") && strcmp(byteorder, "I"))
       {
-        throw std::runtime_error(std::string("WARNING: byteorder '%s' not recognized by LASreader_bil")); //byteorder
+        REprintf( "WARNING: byteorder '%s' not recognized by LASreader_bil\n", byteorder);
       }
     }
     else if (strstr(line, "ulxmap") || strstr(line, "ULXMAP"))
@@ -442,11 +439,11 @@ BOOL LASreaderBIL::read_hdr_file(const CHAR* file_name)
 
   if ((ncols <= 0) || (nrows <= 0) || (nbands <= 0) || (nbits <= 0))
   {
-    throw std::runtime_error(std::string("WARNING: not able to find all entries in HDR file"));
-    throw std::runtime_error(std::string("       ncols  = %d")); //ncols
-    throw std::runtime_error(std::string("       nrows  = %d")); //nrows
-    throw std::runtime_error(std::string("       nbands = %d")); //nbands
-    throw std::runtime_error(std::string("       nbits  = %d")); //nbits
+    REprintf("WARNING: not able to find all entries in HDR file\n");
+    REprintf("       ncols  = %d\n", ncols);
+    REprintf("       nrows  = %d\n", nrows);
+    REprintf("       nbands = %d\n", nbands);
+    REprintf("       nbits  = %d\n", nbits);
     return FALSE;
   }
 
@@ -457,7 +454,7 @@ BOOL LASreaderBIL::read_blw_file(const CHAR* file_name)
 {
   if (file_name == 0)
   {
-    throw std::runtime_error(std::string("ERROR: fine name pointer is zero"));
+    REprintf("ERROR: file name pointer is zero\n");
     return FALSE;
   }
 
@@ -470,7 +467,7 @@ BOOL LASreaderBIL::read_blw_file(const CHAR* file_name)
 
   if ((len == 0) && (file_name_bwl[len] != '.'))
   {
-    throw std::runtime_error(std::string("ERROR: file name '%s' is not a valid BIL file")); //file_name
+    REprintf("ERROR: file name '%s' is not a valid BIL file\n", file_name);
     return FALSE;
   }
 
@@ -491,7 +488,7 @@ BOOL LASreaderBIL::read_blw_file(const CHAR* file_name)
     if (file == 0)
     {
       file_name_bwl[len] = '\0';
-      throw std::runtime_error(std::string("WARNING: cannot open files '%s.blw' or '%s.BLW'")); //file_name_bwl, file_name_bwl
+      REprintf( "WARNING: cannot open files '%s.blw' or '%s.BLW'\n", file_name_bwl, file_name_bwl);
       free(file_name_bwl);
       return FALSE;
     }
@@ -503,36 +500,36 @@ BOOL LASreaderBIL::read_blw_file(const CHAR* file_name)
 
   if (!fgets(line, 256, file))
   {
-    throw std::runtime_error(std::string("WARNING: corrupt world file"));
+    REprintf( "WARNING: corrupt world file\n");
     return FALSE;
   }
   sscanf(line, "%f", &xdim);
   if (!fgets(line, 256, file))
   {
-    throw std::runtime_error(std::string("WARNING: corrupt world file"));
+    REprintf( "WARNING: corrupt world file\n");
     return FALSE;
   }
   if (!fgets(line, 256, file))
   {
-    throw std::runtime_error(std::string("WARNING: corrupt world file"));
+    REprintf( "WARNING: corrupt world file\n");
     return FALSE;
   }
   if (!fgets(line, 256, file))
   {
-    throw std::runtime_error(std::string("WARNING: corrupt world file"));
+    REprintf( "WARNING: corrupt world file\n");
     return FALSE;
   }
   sscanf(line, "%f", &ydim);
   ydim = -1*ydim;
   if (!fgets(line, 256, file))
   {
-    throw std::runtime_error(std::string("WARNING: corrupt world file"));
+    REprintf( "WARNING: corrupt world file\n");
     return FALSE;
   }
   sscanf(line, "%lf", &ulxcenter);
   if (!fgets(line, 256, file))
   {
-    throw std::runtime_error(std::string("WARNING: corrupt world file"));
+    REprintf( "WARNING: corrupt world file\n");
     return FALSE;
   }
   sscanf(line, "%lf", &ulycenter);
@@ -598,9 +595,9 @@ BOOL LASreaderBIL::read_point_default()
         if (fread((void*)&elevation, 4, 1, file) != 1)
         {
 #ifdef _WIN32
-          throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+          REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-          throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+          REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
           npoints = p_count;
           return FALSE;
@@ -612,9 +609,9 @@ BOOL LASreaderBIL::read_point_default()
         if (fread((void*)&elev, 4, 1, file) != 1)
         {
 #ifdef _WIN32
-          throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+          REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-          throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+          REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
           npoints = p_count;
           return FALSE;
@@ -628,9 +625,9 @@ BOOL LASreaderBIL::read_point_default()
       if (fread((void*)&elev, 2, 1, file) != 1)
       {
 #ifdef _WIN32
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
         npoints = p_count;
         return FALSE;
@@ -643,9 +640,9 @@ BOOL LASreaderBIL::read_point_default()
       if (fread((void*)rgb, 1, nbands, file) != (U32)nbands)
       {
 #ifdef _WIN32
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %I64d points\n", row, nrows, col, ncols, p_count);
 #else
-        throw std::runtime_error(std::string("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points")); //row, nrows, col, ncols, p_count
+        REprintf("WARNING: end-of-file after %d of %d rows and %d of %d cols. read %lld points\n", row, nrows, col, ncols, p_count);
 #endif
         npoints = p_count;
         return FALSE;
@@ -688,20 +685,20 @@ BOOL LASreaderBIL::reopen(const CHAR* file_name)
 {
   if (file_name == 0)
   {
-    throw std::runtime_error(std::string("ERROR: fine name pointer is zero"));
+    REprintf("ERROR: file name pointer is zero\n");
     return FALSE;
   }
 
   file = fopen(file_name, "rb");
   if (file == 0)
   {
-    throw std::runtime_error(std::string("ERROR: cannot reopen file '%s'")); //file_name
+    REprintf( "ERROR: cannot reopen file '%s'\n", file_name);
     return FALSE;
   }
 
   if (setvbuf(file, NULL, _IOFBF, 2*LAS_TOOLS_IO_IBUFFER_SIZE) != 0)
   {
-    throw std::runtime_error(std::string("WARNING: setvbuf() failed with buffer size %d")); //2*LAS_TOOLS_IO_IBUFFER_SIZE
+    REprintf( "WARNING: setvbuf() failed with buffer size %d\n", 2*LAS_TOOLS_IO_IBUFFER_SIZE);
   }
 
   col = 0;
@@ -820,8 +817,8 @@ void LASreaderBIL::populate_bounding_box()
 
   if ((header.min_x > 0) != (dequant_min_x > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for min_x from %g to %g.")); //header.min_x, dequant_min_x
-    throw std::runtime_error(std::string("         set scale factor for x coarser than %g with '-rescale'")); //header.x_scale_factor
+    REprintf( "WARNING: quantization sign flip for min_x from %g to %g.\n", header.min_x, dequant_min_x);
+    REprintf( "         set scale factor for x coarser than %g with '-rescale'\n", header.x_scale_factor);
   }
   else
   {
@@ -829,8 +826,8 @@ void LASreaderBIL::populate_bounding_box()
   }
   if ((header.max_x > 0) != (dequant_max_x > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for max_x from %g to %g.")); //header.max_x, dequant_max_x
-    throw std::runtime_error(std::string("         set scale factor for x coarser than %g with '-rescale'")); //header.x_scale_factor
+    REprintf( "WARNING: quantization sign flip for max_x from %g to %g.\n", header.max_x, dequant_max_x);
+    REprintf( "         set scale factor for x coarser than %g with '-rescale'\n", header.x_scale_factor);
   }
   else
   {
@@ -838,8 +835,8 @@ void LASreaderBIL::populate_bounding_box()
   }
   if ((header.min_y > 0) != (dequant_min_y > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for min_y from %g to %g.")); //header.min_y, dequant_min_y
-    throw std::runtime_error(std::string("         set scale factor for y coarser than %g with '-rescale'")); //header.y_scale_factor
+    REprintf( "WARNING: quantization sign flip for min_y from %g to %g.\n", header.min_y, dequant_min_y);
+    REprintf( "         set scale factor for y coarser than %g with '-rescale'\n", header.y_scale_factor);
   }
   else
   {
@@ -847,8 +844,8 @@ void LASreaderBIL::populate_bounding_box()
   }
   if ((header.max_y > 0) != (dequant_max_y > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for max_y from %g to %g.")); //header.max_y, dequant_max_y
-    throw std::runtime_error(std::string("         set scale factor for y coarser than %g with '-rescale'")); //header.y_scale_factor
+    REprintf( "WARNING: quantization sign flip for max_y from %g to %g.\n", header.max_y, dequant_max_y);
+    REprintf( "         set scale factor for y coarser than %g with '-rescale'\n", header.y_scale_factor);
   }
   else
   {
@@ -856,8 +853,8 @@ void LASreaderBIL::populate_bounding_box()
   }
   if ((header.min_z > 0) != (dequant_min_z > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for min_z from %g to %g.")); //header.min_z, dequant_min_z
-    throw std::runtime_error(std::string("         set scale factor for z coarser than %g with '-rescale'")); //header.z_scale_factor
+    REprintf( "WARNING: quantization sign flip for min_z from %g to %g.\n", header.min_z, dequant_min_z);
+    REprintf( "         set scale factor for z coarser than %g with '-rescale'\n", header.z_scale_factor);
   }
   else
   {
@@ -865,8 +862,8 @@ void LASreaderBIL::populate_bounding_box()
   }
   if ((header.max_z > 0) != (dequant_max_z > 0))
   {
-    throw std::runtime_error(std::string("WARNING: quantization sign flip for max_z from %g to %g.")); //header.max_z, dequant_max_z
-    throw std::runtime_error(std::string("         set scale factor for z coarser than %g with '-rescale'")); //header.z_scale_factor
+    REprintf( "WARNING: quantization sign flip for max_z from %g to %g.\n", header.max_z, dequant_max_z);
+    REprintf( "         set scale factor for z coarser than %g with '-rescale'\n", header.z_scale_factor);
   }
   else
   {
